CustomAppBar class

This AppBar just allows us to reuse same style in the app

Inheritance
Implemented types

Constructors

CustomAppBar({Key? key, String? title, List<Widget>? actions, VoidCallback? previousScreenCall, ValueNotifier<bool>? backButtonIsVisibleNotifier, PreferredSizeWidget? bottom, bool showBackButton = true})
Creates a custom app bar.
const

Properties

actions List<Widget>?
A list of Widgets to display in a row after the title widget.
final
backButtonIsVisibleNotifier ValueNotifier<bool>?
Back button visibility notifier
final
bottom PreferredSizeWidget?
This widget appears across the bottom of the app bar.
final
hashCode int
The hash code for this object.
no setterinherited
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
preferredSize Size
The size this widget would prefer if it were otherwise unconstrained.
no setteroverride
previousScreenCall VoidCallback?
A callback that is called when the back button is pressed.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
showBackButton bool
Whether to show the back button. Defaults to true.
final
title String?
The title displayed in the app bar.
final

Methods

build(BuildContext context) Widget
Describes the part of the user interface represented by this widget.
override
createElement() StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
leadingIcon() Widget
Leading Icon
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
titleText(BuildContext context) Widget?
Title text
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited