BasfComponentsLocalizationsPt class

The translations for Portuguese (pt).

Inheritance

Constructors

BasfComponentsLocalizationsPt([String locale = 'pt'])

Properties

cameraNotAvailable → String
No description provided for @cameraNotAvailable.
no setteroverride
close → String
No description provided for @close.
no setteroverride
codeScanSuccessPhrase → String
No description provided for @codeScanSuccessPhrase.
no setteroverride
error → String
No description provided for @error.
no setteroverride
generalAbort → String
No description provided for @generalAbort.
no setteroverride
generalConfirm → String
No description provided for @generalConfirm.
no setteroverride
hashCode → int
The hash code for this object.
no setterinherited
localeName → String
finalinherited
provideCameraPermission → String
No description provided for @provideCameraPermission.
no setteroverride
rescan → String
No description provided for @rescan.
no setteroverride
retry → String
No description provided for @retry.
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
scanQRorBarcode → String
No description provided for @scanQRorBarcode.
no setteroverride
showMorePhrase → String
No description provided for @showMorePhrase.
no setteroverride
warning → String
No description provided for @warning.
no setteroverride

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited