$AssetsRiveGen class

Constructors

$AssetsRiveGen()
const

Properties

emoji → RiveGenImage
File path: assets/rive/emoji.riv
no setter
gears → RiveGenImage
File path: assets/rive/gears.riv
no setter
hashCode → int
The hash code for this object.
no setterinherited
logisticsBox → RiveGenImage
File path: assets/rive/logistics_box.riv
no setter
messageIcon → RiveGenImage
File path: assets/rive/message_icon.riv
no setter
qr → RiveGenImage
File path: assets/rive/qr.riv
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
searchLoop → RiveGenImage
File path: assets/rive/search_loop.riv
no setter
successStatusIcon → RiveGenImage
File path: assets/rive/success_status_icon.riv
no setter
values → List<RiveGenImage>
List of all assets
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited