HydrationErrorBehavior enum
Describes the various caching behaviors when a hydration error occurs.
Values
- overwrite → const HydrationErrorBehavior
-
Overwrite the cached state when a hydration error occurs. Any newly emitted states will be persisted which means previously cached state will be overwritten. This is the default behavior.
- retain → const HydrationErrorBehavior
-
Retain the cached state when a hydration error occurs. Any newly emitted states will not be persisted until hydrate succeeds which means the previously cached state will be retained.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
HydrationErrorBehavior> - A constant List of the values in this enum, in order of their declaration.